@@ -1,6 +1,6 @@
 ;;; (www http) --- HTTP client library
 
-;; Copyright (C) 2008, 2009, 2011, 2012 Thien-Thi Nguyen
+;; Copyright (C) 2008, 2009, 2011, 2012, 2013 Thien-Thi Nguyen
 ;; Copyright (C) 1997, 2001, 2002, 2003, 2004, 2005,
 ;;   2006, 2007 Free Software Foundation, Inc.
 ;;
@@ -33,8 +33,6 @@
             http:message-body
             http:message-headers
             http:message-header
-            http:head
-            http:get
             http:post-form
             http:connect
             http:open
@@ -65,9 +63,7 @@
 ;;
 ;; @example
 ;; http:request
-;; http:head        ; via http:request
-;; http:get         ; likewise
-;; http:post-form   ; likewise
+;; http:post-form   ; via http:request
 ;; @end example
 ;;
 ;;-category: fluid
@@ -145,25 +141,6 @@
   (vector-set! msg 1 (fs "~A" (vector-ref msg 1))))
 
 
-
-;;; HTTP methods.
-
-;; Common methods: HEAD, GET, POST etc.
-
-;; Submit an http request using the @code{HEAD} method on the @var{url}.
-;; The @code{Host} header is automatically included.
-;;
-(define (http:head url)
-  (http:request 'HEAD url))
-
-;; Submit an http request using the @code{GET} method on the @var{url}.
-;; The @code{Host} header is automatically included.
-;;
-(define (http:get url)
-  ;; FIXME: if http:open returns an old connection that has been
-  ;; closed remotely, this will fail.
-  (http:request 'GET url))
-
 ;; Submit an http request using the @code{POST} method on the @var{url}.
 ;; @var{extra-headers} is a list of extra headers, each a string of form
 ;; "@var{name}: @var{value} @dots{}".
@@ -390,20 +367,6 @@
 ;; or read in one swoop (if @code{Content-Length} is given),
 ;; or from multiple inexact chunks (the default).
 ;;
-;; For backward compatability, instead of a thunk returning four values,
-;; you can also specify the four values directly.
-;; @strong{NB: Support for specifying four values directly will
-;; NO LONGER BE AVAILABLE after 2013-05-15.}@footnote{Out of an explicit
-;; @code{call-with-values} context, Guile 2.x will silently discard all
-;; values following the ``expected number'' (one, in this case):
-;;
-;; @example
-;; (list 'custom (values P1 P2 P3 P4))
-;; @result{} (custom P1)
-;; @end example
-;;
-;; This is apparently allowed under R5RS and R6RS.}
-;;
 ;; @item If @var{flags} contains the symbol @code{no-cat}, then all
 ;; multi-chunk transfers are not ``concatenated''; instead, the message
 ;; body is the list of chunk data (string, @code{u8} or @code{custom}),
